@@ -1,13 +1,12 @@
 package Inferno::RegMgr::Lookup;
-
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-# update POD & Changes & README
-use version; our $VERSION = qv('0.1.0');
+our $VERSION = 'v1.0.0';
 
-# update DEPENDENCIES in POD & Makefile.PL & README
 use Scalar::Util qw( weaken );
 use EV;
 use Inferno::RegMgr::Utils qw( run_callback );
@@ -67,6 +66,8 @@ sub REFRESH {}
 1; # Magic true value required at end of module
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Inferno::RegMgr::Lookup - Search services in OS Inferno's registry(4)
@@ -74,7 +75,7 @@ Inferno::RegMgr::Lookup - Search services in OS Inferno's registry(4)
 
 =head1 VERSION
 
-This document describes Inferno::RegMgr::Lookup version 0.1.0
+This document describes Inferno::RegMgr::Lookup version v1.0.0
 
 
 =head1 SYNOPSIS
@@ -110,7 +111,7 @@ Accept HASHREF with options:
  method     OPTIONAL user callback method (if {cb} is CLASS/OBJECT)
 
 If there will be no option attr or it value will be empty hash - all
-services will be retured.
+services will be returned.
 
 If some attribute value will be '*' then all services which has that
 attribute with any value will be returned.
@@ -130,62 +131,63 @@ of these services):
 None.
 
 
-=head1 CONFIGURATION AND ENVIRONMENT
+=head1 SUPPORT
 
-Inferno::RegMgr::Lookup requires no configuration files or environment variables.
+=head2 Bugs / Feature Requests
 
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-Inferno-RegMgr/issues>.
+You will be notified automatically of any progress on your issue.
 
-=head1 DEPENDENCIES
+=head2 Source Code
 
- EV
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
 
+L<https://github.com/powerman/perl-Inferno-RegMgr>
 
-=head1 INCOMPATIBILITIES
+    git clone https://github.com/powerman/perl-Inferno-RegMgr.git
 
-None reported.
+=head2 Resources
 
+=over
 
-=head1 BUGS AND LIMITATIONS
+=item * MetaCPAN Search
 
-No bugs have been reported.
+L<https://metacpan.org/search?q=Inferno-RegMgr>
 
-Please report any bugs or feature requests to
-C<bug-regmgr-lookup@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/Inferno-RegMgr>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Inferno-RegMgr>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=Inferno-RegMgr>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/Inferno-RegMgr>
+
+=back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman-asdf@ya.ru> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009, Alex Efros C<< <powerman-asdf@ya.ru> >>. All rights reserved.
+This software is Copyright (c) 2009-2010 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+=cut
