@@ -1,13 +1,12 @@
 package Inferno::RegMgr::TCP;
-
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-# update POD & Changes & README
-use version; our $VERSION = qv('0.1.3');
+our $VERSION = 'v1.0.0';
 
-# update DEPENDENCIES in POD & Makefile.PL & README
 use Scalar::Util qw( weaken );
 use IO::Stream;
 use Inferno::RegMgr::Utils qw( run_callback quote attr parse_svc );
@@ -136,6 +135,8 @@ sub _cb_find {
 1; # Magic true value required at end of module
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Inferno::RegMgr::TCP - Access OS Inferno's registry(4) files using TCP ports
@@ -143,7 +144,7 @@ Inferno::RegMgr::TCP - Access OS Inferno's registry(4) files using TCP ports
 
 =head1 VERSION
 
-This document describes Inferno::RegMgr::TCP version 0.1.2
+This document describes Inferno::RegMgr::TCP version v1.0.0
 
 
 =head1 SYNOPSIS
@@ -392,66 +393,69 @@ Called method require that option in it HASHREF with params.
 =back
 
 
-=head1 CONFIGURATION AND ENVIRONMENT
-
-Inferno::RegMgr::TCP requires no configuration files or environment variables.
-
-
-=head1 DEPENDENCIES
-
- version
- IO::Stream
-
-
-=head1 INCOMPATIBILITIES
-
-None reported.
-
-
-=head1 BUGS AND LIMITATIONS
+=head1 LIMITATIONS
 
 It's impossible to unregister (delete) "persist" service.
 It's impossible to register different services using different user accounts.
 
-No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<bug-regmgr-tcp@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-Inferno-RegMgr/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
+
+L<https://github.com/powerman/perl-Inferno-RegMgr>
+
+    git clone https://github.com/powerman/perl-Inferno-RegMgr.git
+
+=head2 Resources
+
+=over
+
+=item * MetaCPAN Search
+
+L<https://metacpan.org/search?q=Inferno-RegMgr>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/Inferno-RegMgr>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Inferno-RegMgr>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=Inferno-RegMgr>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/Inferno-RegMgr>
+
+=back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman-asdf@ya.ru> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009, Alex Efros C<< <powerman-asdf@ya.ru> >>. All rights reserved.
+This software is Copyright (c) 2009-2010 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+=cut
